AuthResponse class final
Represents the result of a login attempt.
- Annotations
-
- @external
Constructors
- AuthResponse(String? clientInfo, DittoException? exception)
-
const
Properties
- clientInfo → String?
-
JSON-formatted client info returned by the authentication webhook, if any.
This field is populated for both successful and failed login attempts and
is only
nullwhen no client info was provided by the webhook.final - exception → DittoException?
-
If the login attempt was successful, this property will be
null. If the login attempt failed, this property will contain a DittoException object with details about the error.final - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited