ConnectionBuilder class final

Builder class for Connection

Annotations
  • @external

Constructors

ConnectionBuilder({required String id, required String peer1, required String peer2, required ConnectionType connectionType})

Properties

connectionType ConnectionType
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pair
peer1 String
getter/setter pair
peer2 String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() Connection
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited