ConnectionRequest class interface

Contains information about a remote peer that has requested a connection.

Connection requests and their authorization are scoped to a specific Ditto peer and connection type.

Annotations
  • @external

Properties

connectionType ConnectionType
The network transport of this connection request.
no setter
hashCode int
The hash code for this object.
no setterinherited
identityServiceMetadata Map<String, dynamic>
Metadata for the remote peer that is provided by the identity service.
no setter
identityServiceMetadataJsonString String
JSON-encoded metadata for the remote peer that is provided by the identity service.
no setter
peerKeyString String
The unique peer key of the remote peer.
no setter
peerMetadata Map<String, dynamic>
Metadata associated with the remote peer.
no setter
peerMetadataJsonString String
JSON-encoded metadata associated with the remote peer.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited