DittoConfigBuilder class final

Builder class for DittoConfig

Annotations
  • @external

Constructors

DittoConfigBuilder({required String? databaseID, required DittoConfigConnectBuilder connect, required String? persistenceDirectory, required DittoConfigExperimentalBuilder experimental})

Properties

connect DittoConfigConnectBuilder
getter/setter pair
databaseID String?
getter/setter pair
experimental DittoConfigExperimentalBuilder
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
persistenceDirectory String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() DittoConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited