DittoConfigConnectServerBuilder class final

Builder class for DittoConfigConnectServer

Inheritance
Annotations
  • @external

Constructors

DittoConfigConnectServerBuilder({required String url})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
getter/setter pair

Methods

build() DittoConfigConnectServer
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited