QueryResult class interface

Represents the result of executing a DQL query.

Annotations
  • @external

Properties

commitID int?
The commit ID associated with this query result, if any.
no setter
hashCode int
The hash code for this object.
no setterinherited
items Iterable<QueryResultItem>
Individual items matching a DQL query.
no setter
mutatedDocumentIDs Iterable<DocumentID>
IDs of documents that were mutated locally by a mutating DQL query passed to Store.execute.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited