SmallPeerInfo class final

An object that provides access to Ditto's small peer info APIs.

An instance of SmallPeerInfo can be obtained from Ditto.smallPeerInfo:

final ditto = await Ditto.open(/* ... */);
final smallPeerInfo = ditto.smallPeerInfo;

This class is not user-constructible.

Annotations
  • @external

Properties

hashCode int
The hash code for this object.
no setterinherited
isEnabled bool
getter/setter pair
metadata Map<String, dynamic>
getter/setter pair
metadataJsonString String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited