StoreObserver class interface

An object that tracks when results for its query change.

Create a StoreObserver by calling Store.registerObserver. The store observer will remain active until the owning Ditto object is closed or cancel is called.

Annotations
  • @external

Properties

changes Stream<QueryResult>
A convenience API that produces a Stream of QueryResults.
no setter
hashCode int
The hash code for this object.
no setterinherited
isCancelled bool
Whether this StoreObserver is cancelled.
no setter
queryArguments Map<String, dynamic>
The query arguments that were passed to Store.registerObserver.
final
queryString String
The query string that was passed to Store.registerObserver.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel() → void
Cancel observation. No-op if this StoreObserver is already cancelled.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited