Differ class final
Calculates diffs between arrays of QueryResultItems.
Use a Differ with a StoreObserver to get the diff between subsequent query results delivered by the store observer.
- Annotations
-
- @external
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
diff(
List< QueryResultItem> items) → Diff -
Calculate the diff of the provided
itemsagainst the last set of items that were passed to this differ. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited